package nccloud.api.cmp.pub.add;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import javax.ws.rs.Consumes;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.Produces;
import nc.bs.dao.BaseDAO;
import nc.bs.framework.common.NCLocator;
import nc.bs.logging.Logger;
import nc.bs.trade.business.HYPubBO;
import nc.impl.pubapp.pattern.database.DataAccessUtils;
import nc.md.data.access.NCObject;
import nc.md.model.MetaDataException;
import nc.md.persist.framework.IMDPersistenceQueryService;
import nc.pubitf.cmp.paybill.ICmpPayBillPubService;
import nc.pubitf.para.SysInitQuery;
import nc.vo.bd.bankaccount.BankAccSubVO;
import nc.vo.bd.inoutbusiclass.InoutBusiClassVO;
import nc.vo.cmp.bill.BillAggVO;
import nc.vo.cmp.bill.BillDetailVO;
import nc.vo.cmp.bill.BillVO;
import nc.vo.cmp.util.StringUtils;
import nc.vo.pub.AggregatedValueObject;
import nc.vo.pub.BusinessException;
import nc.vo.pub.CircularlyAccessibleValueObject;
import nc.vo.pub.billtype.BilltypeVO;
import nc.vo.pub.lang.UFBoolean;
import nc.vo.pub.lang.UFDate;
import nc.vo.pub.lang.UFDateTime;
import nc.vo.pubapp.pattern.data.IRowSet;
import nc.vo.pubapp.pattern.exception.ExceptionUtils;
import nc.vo.tmpub.util.StringUtil;
import nc.vo.tmpub.util.TMCurrencyUtil;
import nccloud.api.rest.utils.ResultMessageUtil;
import nccloud.api.tmpub.common.TMpubCommonRefTranslate;
import org.json.JSONString;

@Path("cmp/paybillAdd")
/* loaded from: PayBillAddResource.class */
public class PayBillAddResource extends AbstractCmpBillAddResource {
    @Path("addBill")
    @Consumes({"application/json"})
    @POST
    @Produces({"application/json"})
    public JSONString addBill(Map<String, Object> varMap) {
        return super.addBill(varMap);
    }

    protected AggregatedValueObject initAggVO() {
        return new BillAggVO();
    }

    protected CircularlyAccessibleValueObject initParentVO() {
        return new BillVO();
    }

    protected CircularlyAccessibleValueObject[] initChildVO(int size) {
        BillDetailVO[] billDetailVOs = new BillDetailVO[size];
        for (int i = 0; i < size; i++) {
            billDetailVOs[i] = new BillDetailVO();
        }
        return billDetailVOs;
    }

    protected String[] getHeadNotNullFields() {
        return new String[]{"pk_org", "bill_date"};
    }

    protected String[] getBodyNotNullFields() {
        return new String[]{"pk_org", "pk_currtype", "pay_primal"};
    }

    protected void dataNotNullValidate(AggregatedValueObject aggvo) throws BusinessException {
        super.dataNotNullValidate(aggvo);
        BillDetailVO[] childVOs = aggvo.getChildrenVO();
        UFBoolean bipSkSend = UFBoolean.FALSE;
        try {
            bipSkSend = SysInitQuery.getParaBoolean((String) aggvo.getParentVO().getAttributeValue("pk_org"), "BIP_SKSEND");
        } catch (Exception e) {
            Logger.error("鏈\ue045敞鍐屽弬鏁版潯鐩\ue1c6細BIP_SKSEND");
        }
        for (BillDetailVO childVO : childVOs) {
            int num = 0;
            if (StringUtil.isNotNull(childVO.getPk_oppaccount())) {
                num = 0 + 1;
            }
            if (StringUtil.isNotNull(childVO.getMon_account())) {
                num++;
            }
            if (StringUtil.isNotNull(childVO.getNote_no())) {
                num++;
            }
            if (!bipSkSend.booleanValue()) {
                if (num == 0) {
                    throw new BusinessException("琛ㄤ綋鏈\ue101柟閾惰\ue511璐︽埛銆佺幇閲戣处鎴枫�佺エ鎹\ue1bc彿锛堝晢涓氭眹绁ㄥ彿锛変笉鑳藉悓鏃朵负绌�");
                }
                if (num > 1) {
                    throw new BusinessException("琛ㄤ綋鏈\ue101柟閾惰\ue511璐︽埛銆佺幇閲戣处鎴枫�佺エ鎹\ue1bc彿锛堝晢涓氭眹绁ㄥ彿锛変笉鑳藉悓鏃舵湁鍊�");
                }
            }
            if (childVO.getObjecttype() != null) {
                if (childVO.getObjecttype().intValue() == 0 && StringUtil.isNull(childVO.getPk_customer())) {
                    throw new BusinessException("浜ゆ槗瀵硅薄绫诲瀷涓哄\ue179鎴锋椂锛屽\ue179鎴蜂笉鑳戒负绌�");
                }
                if (childVO.getObjecttype().intValue() == 1 && StringUtil.isNull(childVO.getPk_supplier())) {
                    throw new BusinessException("浜ゆ槗瀵硅薄绫诲瀷涓轰緵搴斿晢鏃讹紝渚涘簲鍟嗕笉鑳戒负绌�");
                }
                if (childVO.getObjecttype().intValue() == 2 && StringUtil.isNull(childVO.getPk_dept())) {
                    throw new BusinessException("浜ゆ槗瀵硅薄绫诲瀷涓洪儴闂ㄦ椂锛岄儴闂ㄤ笉鑳戒负绌�");
                }
                if (childVO.getObjecttype().intValue() == 3 && StringUtil.isNull(childVO.getPk_busiman())) {
                    throw new BusinessException("浜ゆ槗瀵硅薄绫诲瀷涓轰汉鍛樻椂锛屼笟鍔″憳涓嶈兘涓虹┖");
                }
            }
        }
    }

    protected AggregatedValueObject fillData(AggregatedValueObject aggvo) throws BusinessException {
        BillVO parentVO = aggvo.getParentVO();
        BillDetailVO[] childVOs = aggvo.getChildrenVO();
        parentVO.setBillclass("fj");
        parentVO.setBill_type("F5");
        parentVO.setSource_flag("2");
        parentVO.setBill_status(-10);
        if (StringUtil.isNull(parentVO.getCreator())) {
            parentVO.setCreator("NC_USER0000000000000");
        }
        if (StringUtil.isNull(parentVO.getBillmaker())) {
            parentVO.setBillmaker(parentVO.getCreator());
        }
        parentVO.setCreator(parentVO.getBillmaker());
        parentVO.setCreationtime(new UFDateTime());
        for (BillDetailVO childVO : childVOs) {
            childVO.setBillclass(parentVO.getBillclass());
            childVO.setCreator(parentVO.getCreator());
            childVO.setPk_group(parentVO.getPk_group());
            childVO.setBill_date(parentVO.getBill_date());
            childVO.setBill_type("F5");
            childVO.setDirection(-1);
            childVO.setCreationtime(parentVO.getCreationtime());
            childVO.setCreator(parentVO.getCreator());
            childVO.setTeade_type(parentVO.getTrade_type());
            childVO.setPk_tradetypeid(parentVO.getPk_tradetypeid());
        }
        return fillMoneyAndRate(aggvo);
    }

    private AggregatedValueObject fillMoneyAndRate(AggregatedValueObject aggvo) throws BusinessException {
        BillDetailVO[] childVOs = aggvo.getChildrenVO();
        for (BillDetailVO childVO : childVOs) {
            String pk_group_b = childVO.getPk_group();
            String pk_org_b = childVO.getPk_org();
            String pk_currtype_b = childVO.getPk_currtype();
            UFDate bill_date_b = childVO.getBill_date();
            if (childVO.getGlobal_rate() == null) {
                childVO.setGlobal_rate(TMCurrencyUtil.getGlobalCurrRate(pk_org_b, pk_currtype_b, bill_date_b));
            }
            if (childVO.getGroup_rate() == null) {
                childVO.setGroup_rate(TMCurrencyUtil.getGroupCurrRate(pk_group_b, pk_org_b, pk_currtype_b, bill_date_b));
            }
            if (childVO.getLocal_rate() == null) {
                childVO.setLocal_rate(TMCurrencyUtil.getOrgCurrRate(pk_org_b, pk_currtype_b, bill_date_b));
            }
            if (childVO.getGlobal_local_pay() == null) {
                childVO.setGlobal_local_pay(TMCurrencyUtil.getGlobalLocalMoney(pk_org_b, pk_currtype_b, childVO.getPay_primal(), childVO.getGlobal_rate(), childVO.getLocal_rate(), bill_date_b));
            }
            if (childVO.getGroup_local_pay() == null) {
                childVO.setGroup_local_pay(TMCurrencyUtil.getGroupLocalMoney(pk_group_b, pk_org_b, pk_currtype_b, childVO.getPay_primal(), childVO.getGlobal_rate(), childVO.getLocal_rate(), bill_date_b));
            }
            if (childVO.getPay_local() == null) {
                childVO.setPay_local(TMCurrencyUtil.getOrgLocalMoney(pk_org_b, pk_currtype_b, childVO.getPay_primal(), childVO.getLocal_rate(), bill_date_b));
            }
        }
        return aggvo;
    }

    protected JSONString addBill(AggregatedValueObject aggvo) throws BusinessException {
        valedictionRepeatSave(aggvo);
        BillAggVO[] aggVOs = {(BillAggVO) aggvo};
        BillAggVO[] newAggVOs = ((ICmpPayBillPubService) NCLocator.getInstance().lookup(ICmpPayBillPubService.class)).save(aggVOs);
        String bill_no = newAggVOs[0].getParentVO().getBill_no();
        String pk_paybill = newAggVOs[0].getParentVO().getPk_paybill();
        HashMap<String, String> map = new HashMap<>();
        map.put("bill_no", bill_no);
        map.put("pk_paybill", pk_paybill);
        return ResultMessageUtil.toJSON(map);
    }

    private void valedictionRepeatSave(AggregatedValueObject aggvo) {
        String def22 = (String) aggvo.getParentVO().getAttributeValue("def22");
        String def23 = (String) aggvo.getParentVO().getAttributeValue("def22");
        if (StringUtils.isEmpty(def22)) {
            return;
        }
        String querysql = "select bill_no from cmp_paybill where def22= '" + def22 + "' and nvl(dr,0)=0 ";
        DataAccessUtils accessUtils = new DataAccessUtils();
        IRowSet row = accessUtils.query(querysql);
        while (row.next()) {
            ExceptionUtils.wrappBusinessException("鍙稿簱鍗曟嵁鍙凤細" + def23 + "宸插瓨鍦\ue7d2紝璇锋\ue5c5鏌\ue654CC绯荤粺涓\ue15d粯娆剧粨绠楀崟鍗曟嵁鍙凤細" + row.getString(0));
        }
    }

    public AggregatedValueObject getAggVO(Map<String, Object> varMap) throws BusinessException, ClassCastException {
        if (varMap.isEmpty()) {
            throw new BusinessException("浼犲叆鍙傛暟涓嶆\ue11c纭�");
        }
        BillAggVO aggvo = initAggVO();
        return converToBillVO(varMap, aggvo);
    }

    private AggregatedValueObject converToBillVO(Map<String, Object> varMap, AggregatedValueObject aggVO) throws BusinessException {
        Map<String, Object> headMap = (Map) varMap.get("head");
        TMpubCommonRefTranslate.translateExToNCAdd(headMap);
        BillVO headvo = (BillVO) getVO(headMap, new BillVO());
        headvo.setPk_org_v(TMpubCommonRefTranslate.getOrgUnit_V((String) headvo.getAttributeValue("pk_org")));
        getPk_tradetypeid(headvo);
        if (StringUtil.isNull(headvo.getBillmaker_date())) {
            headvo.setBillmaker_date(new UFDate());
        }
        aggVO.setParentVO(headvo);
        List<Map<String, Object>> bodyList = (List) varMap.get("body");
        BillDetailVO[] bodysVO = new BillDetailVO[bodyList.size()];
        for (int i = 0; i < bodyList.size(); i++) {
            Map<String, Object> bodyMap = bodyList.get(i);
            TMpubCommonRefTranslate.translateExToNCAdd(bodyMap);
            bodysVO[i] = (BillDetailVO) getVO(bodyMap, new BillDetailVO());
            bodysVO[i].setPk_org((String) headvo.getAttributeValue("pk_org"));
            bodysVO[i].setPk_org_v((String) headvo.getAttributeValue("pk_org_v"));
            bodysVO[i].setPk_busiorg((String) headvo.getAttributeValue("pk_org"));
            bodysVO[i].setPk_busiorg_v((String) headvo.getAttributeValue("pk_org_v"));
            bodysVO[i].setPk_oppaccount(TMpubCommonRefTranslate.translatebankacc((String) headvo.getAttributeValue("pk_org"), bodysVO[i].getPk_oppaccount(), (String) bodysVO[i].getAttributeValue("pk_currtype")));
            if (StringUtil.isNotNull(bodysVO[i].getMon_account())) {
                bodysVO[i].setMon_account(TMpubCommonRefTranslate.translatecashkacc((String) headvo.getAttributeValue("pk_org"), bodysVO[i].getMon_account(), (String) bodysVO[i].getAttributeValue("pk_currtype")));
            } else {
                bodysVO[i].setMon_account((String) null);
            }
            bodysVO[i].setPk_supplier(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_supplier", bodysVO[i].getPk_supplier()));
            bodysVO[i].setPk_customer(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_customer", bodysVO[i].getPk_customer()));
            bodysVO[i].setPk_busiman(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_busiman", bodysVO[i].getPk_busiman()));
            String pk_trader = null;
            String accnum = bodysVO[i].getPk_account();
            if (StringUtil.isNotNull(bodysVO[i].getPk_supplier())) {
                pk_trader = bodysVO[i].getPk_supplier();
            } else if (StringUtil.isNotNull(bodysVO[i].getPk_customer())) {
                pk_trader = bodysVO[i].getPk_customer();
            } else if (StringUtil.isNotNull(bodysVO[i].getPk_busiman())) {
                pk_trader = bodysVO[i].getPk_busiman();
            }
            Integer objecttype = bodysVO[i].getObjecttype();
            if (StringUtil.isNotNull(accnum) && objecttype != null && objecttype.intValue() != 4) {
                String pk_account = getOppAccount(accnum, pk_trader, objecttype, bodysVO[i].getPk_currtype());
                if (StringUtils.isEmpty(pk_account)) {
                    throw new BusinessException("瀵规柟璐︽埛娌℃湁鍦ㄧ郴缁熶腑缁存姢鎴栦笉灞炰簬璇ヤ氦鏄撳\ue1ee璞★紒");
                }
                bodysVO[i].setPk_account(pk_account);
            }
            bodysVO[i].setBankroll_projet(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "bankroll_projet", bodysVO[i].getBankroll_projet()));
            bodysVO[i].setPk_subjct(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_subjct", bodysVO[i].getPk_subjct()));
            bodysVO[i].setPk_dept(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_dept", bodysVO[i].getPk_dept()));
            bodysVO[i].setCash_item(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "cash_item", bodysVO[i].getCash_item()));
            List<InoutBusiClassVO> col = (List) new BaseDAO().retrieveByClause(InoutBusiClassVO.class, " code='" + bodysVO[i].getPk_recproject() + "'");
            if (col == null || col.size() < 1) {
                throw new RuntimeException("鏈\ue045煡璇㈠埌鏀舵敮椤圭洰锛岃\ue1ec妫�鏌ョ紪鐮併��" + bodysVO[i].getPk_recproject() + "銆�");
            }
            bodysVO[i].setPk_recproject(col.get(0).getPk_inoutbusiclass());
            bodysVO[i].setPk_jobid(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "pk_jobid", bodysVO[i].getPk_jobid()));
            bodysVO[i].setCinventoryid(TMpubCommonRefTranslate.translateExToNCWithOrg(bodysVO[i].getPk_org(), "cinventoryid", bodysVO[i].getCinventoryid()));
        }
        aggVO.setChildrenVO(bodysVO);
        return aggVO;
    }

    private void getPk_tradetypeid(BillVO billVO) throws MetaDataException {
        NCObject obVO;
        String trade_type = billVO.getTrade_type();
        String pk_goup = billVO.getPk_group();
        IMDPersistenceQueryService query = (IMDPersistenceQueryService) NCLocator.getInstance().lookup(IMDPersistenceQueryService.class);
        String whereCondStr = " pk_group = '" + pk_goup + "' and (pk_billtypecode = '" + trade_type + "' or billtypename = '" + trade_type + "') ";
        NCObject[] billtypes = query.queryBillOfNCObjectByCond(BilltypeVO.class, whereCondStr, false);
        if (billtypes != null && billtypes.length > 0 && (obVO = billtypes[0]) != null && obVO.getContainmentObject() != null && (obVO.getContainmentObject() instanceof BilltypeVO)) {
            BilltypeVO billtypevo = (BilltypeVO) obVO.getContainmentObject();
            if (billtypevo.getPk_billtypecode().equals(trade_type) || billtypevo.getBilltypename().equals(trade_type)) {
                billVO.setPk_tradetypeid(billtypevo.getPk_billtypeid());
                billVO.setTrade_type(billtypevo.getPk_billtypecode());
            }
        }
    }

    private String getOppAccount(String accnum, String pk_trader, Integer objecttype, String pk_currtype) throws BusinessException {
        HYPubBO bo = new HYPubBO();
        BankAccSubVO[] subVOs = null;
        if (objecttype.intValue() == 0 || objecttype.intValue() == 1) {
            String whereSql = " exists (select 1 from bd_custbank where bd_custbank.pk_bankaccsub = bd_bankaccsub.pk_bankaccsub and pk_cust ='" + pk_trader + "') and bd_bankaccsub.pk_currtype='" + pk_currtype + "' and (bd_bankaccsub.accnum='" + accnum + "' or bd_bankaccsub.accname = '" + accnum + "' or bd_bankaccsub.pk_bankaccsub = '" + accnum + "') ";
            subVOs = bo.queryByCondition(BankAccSubVO.class, whereSql);
        } else if (objecttype.intValue() == 2 || objecttype.intValue() == 3) {
            String whereSql2 = " exists (select 1 from bd_psnbankacc where bd_psnbankacc.pk_bankaccsub = bd_bankaccsub.pk_bankaccsub and pk_psndoc ='" + pk_trader + "') and bd_bankaccsub.pk_currtype = '" + pk_currtype + "' and (bd_bankaccsub.accnum='" + accnum + "' or bd_bankaccsub.accname = '" + accnum + "' or bd_bankaccsub.pk_bankaccsub = '" + accnum + "') ";
            subVOs = (BankAccSubVO[]) bo.queryByCondition(BankAccSubVO.class, whereSql2);
        }
        if (subVOs != null && subVOs.length > 0) {
            return subVOs[0].getPk_bankaccsub();
        }
        return null;
    }

    private CircularlyAccessibleValueObject getVO(Map<String, Object> head, CircularlyAccessibleValueObject vo) {
        Set<String> keys = head.keySet();
        for (String key : keys) {
            vo.setAttributeValue(key, head.get(key));
        }
        return vo;
    }
}
